@@ -26,7 +26,8 @@ riemann_attribute_new (void)
 {
   riemann_attribute_t *attrib;
 
-  attrib = malloc (sizeof (riemann_attribute_t));
+  attrib = (riemann_attribute_t *)
+    malloc (sizeof (riemann_attribute_t));
   attribute__init (attrib);
   return attrib;
 }
@@ -103,3 +104,15 @@ riemann_attribute_create (const char *key, const char *value)
 
   return attrib;
 }
+
+riemann_attribute_t *
+riemann_attribute_clone (const riemann_attribute_t *attrib)
+{
+  if (!attrib)
+    {
+      errno = EINVAL;
+      return NULL;
+    }
+
+  return riemann_attribute_create (attrib->key, attrib->value);
+}
