@@ -18,6 +18,7 @@
 #include <riemann/riemann-client.h>
 
 #include <errno.h>
+#include <inttypes.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -77,7 +78,7 @@ typedef int (*cmd_t) (int argc, char *argv[]);
 
 static struct
 {
-  char *command;
+  const char *command;
   cmd_t handler;
   int (*cmp) (const char *s1, const char *s2);
 } command_map[] = {
